==> models_base-1.4.0.tar.gz: lib/src/base/proxy_article_base.dart <==
import 'dart:convert';

abstract class ArticleProxyAbstract {
  final int lineId;
  int get productId => lineId;
  final int articleId;
  final int id;
  final bool status;
  final int proxyLineId;
  final int proxyArticleId;

  const ArticleProxyAbstract({
    required this.lineId,
    required this.articleId,
    required this.id,
    required this.proxyLineId,
    required this.proxyArticleId,
    this.status = true,
  });

  String get text {
    return 'ArticleProxy $lineId.$articleId.$id';
  }

  @override
  String toString() {
    return '''
ArticleProxy(
    lineId: $lineId,
    articleId: $articleId,
    id: $id,
    'proxyArticleId': $proxyArticleId,
    'proxyLineId': $proxyLineId,
    status: $status,
''';
  }

  Map<String, dynamic> toMap() {
    return {
      'lineId': lineId,
      'articleId': articleId,
      'id': id,
      'proxyArticleId': proxyArticleId,
      'proxyLineId': proxyLineId,
      'status': status,
    };
  }

  String toJson() => json.encode(toMap());

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is ArticleProxyAbstract &&
        other.lineId == lineId &&
        other.articleId == articleId &&
        other.id == id &&
        other.proxyLineId == proxyLineId &&
        other.proxyArticleId == proxyArticleId &&
        other.status == status;
  }

  @override
  int get hashCode {
    return lineId.hashCode ^
        articleId.hashCode ^
        id.hashCode ^
        status.hashCode ^
        proxyArticleId.hashCode & proxyLineId.hashCode;
  }
}

==> models_base-1.4.4.tar.gz: lib/src/base/proxy_article_base.dart <==
import 'dart:convert';

abstract class ArticleProxyAbstract {
  final int calibreId;
  int get productId => calibreId;
  final int articleId;
  final int id;
  final bool status;
  final int proxyCalibreId;
  final int proxyArticleId;

  const ArticleProxyAbstract({
    required this.calibreId,
    required this.articleId,
    required this.id,
    required this.proxyCalibreId,
    required this.proxyArticleId,
    this.status = true,
  });

  String get text {
    return 'ArticleProxy $calibreId.$articleId.$id';
  }

  @override
  String toString() {
    return '''
ArticleProxy(
    calibreId: $calibreId,
    articleId: $articleId,
    id: $id,
    'proxyArticleId': $proxyArticleId,
    'proxyCalibreId': $proxyCalibreId,
    status: $status,
''';
  }

  Map<String, dynamic> toMap() {
    return {
      'calibreId': calibreId,
      'articleId': articleId,
      'id': id,
      'proxyArticleId': proxyArticleId,
      'proxyCalibreId': proxyCalibreId,
      'status': status,
    };
  }

  String toJson() => json.encode(toMap());

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is ArticleProxyAbstract &&
        other.calibreId == calibreId &&
        other.articleId == articleId &&
        other.id == id &&
        other.proxyCalibreId == proxyCalibreId &&
        other.proxyArticleId == proxyArticleId &&
        other.status == status;
  }

  @override
  int get hashCode {
    return calibreId.hashCode ^
        articleId.hashCode ^
        id.hashCode ^
        status.hashCode ^
        proxyArticleId.hashCode & proxyCalibreId.hashCode;
  }
}
